package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERBitString;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;

public class IssuerSerial extends ASN1Encodable {
   GeneralNames issuer;
   DERInteger serial;
   DERBitString issuerUID;

   public static IssuerSerial getInstance(Object obj) {
      if (obj != null && !(obj instanceof IssuerSerial)) {
         if (obj instanceof ASN1Sequence) {
            return new IssuerSerial((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (IssuerSerial)obj;
      }
   }

   public static IssuerSerial getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(ASN1Sequence.getInstance(obj, explicit));
   }

   public IssuerSerial(ASN1Sequence seq) {
      if (seq.size() != 2 && seq.size() != 3) {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      } else {
         this.issuer = GeneralNames.getInstance(seq.getObjectAt(0));
         this.serial = DERInteger.getInstance(seq.getObjectAt(1));
         if (seq.size() == 3) {
            this.issuerUID = DERBitString.getInstance(seq.getObjectAt(2));
         }

      }
   }

   public IssuerSerial(GeneralNames issuer, DERInteger serial) {
      this.issuer = issuer;
      this.serial = serial;
   }

   public GeneralNames getIssuer() {
      return this.issuer;
   }

   public DERInteger getSerial() {
      return this.serial;
   }

   public DERBitString getIssuerUID() {
      return this.issuerUID;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.issuer);
      var10001.add(this.serial);
      DERBitString var2;
      if ((var2 = this.issuerUID) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
